#!/bin/sh
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2008, 2012 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
#
# This is a script that gathers up information for problem determination.
# The files are created and stored in the AEM directory
#
# The Director logs should also be collected using the getlogs command
#
# Change log:
# 1.1 MRV created
# 1.2 MRV Minor fixes and additions
# 1.3 MRV Added Dir path and Active checks
# 1.4 MRV Added AEM Dir path checks and table stats
# 1.5 MRV Updated for AIX tar without zip option
# 1.6 MRV Added new dump commands
# 1.7 MRV Reduce file system output to just AEM, new dump commands and userid check
# 1.8 MRV Minor tweaks for cdsa
# 1.9 MRV Add support for smcli options
#

AEM_MEDIC_VER=1.9

echo ""
echo "AEM Medic $AEM_MEDIC_VER"
echo ""

# Some basic help
if [[ "$1" = "-?"  || "$1" = "-h" || "$1" = "-help" ]]; then
   echo "AEM Medic optional options are:  [ -user userid  -pw password ]"
   echo "These options will be passed directly into the smcli calls and are required when using LDAP."
   exit 1
fi   

# Find Director paths
BIN_DIR=`which /opt/ibm/director/bin/smstatus 2>/dev/null`
if [ $? -gt 0 ] ; then
    echo "Director not in PATH, make sure running with proper administrator userid"
    exit 1
fi

# Setup Director paths
BIN_DIR=`dirname $BIN_DIR`
DIR_DIR=`dirname $BIN_DIR`
LWI_DIR=$DIR_DIR/lwi
AEM_DIR=$DIR_DIR/ActiveEnergyManager
PATH=$BIN_DIR:$PATH

# Check if Director is Active
DIR_STATUS=`$BIN_DIR/smstatus 1> /dev/null 2>&1`
if [ $? -gt 0 ] ; then
  echo "Director is not started. AEM Medic requires that Director is active to collect diagnostic information."
  exit 2
fi

# Check if AEM_DIR is ok
if [ ! -d $AEM_DIR ] ; then
  echo "AEM not properly installed. Missing directory $AEM_DIR"
  exit 2
fi

# Check if user can run Director CLIs
USERID_STATUS=`$BIN_DIR/smcli $* lsbundle 1> /dev/null 2>&1`
if [ $? -gt 0 ] ; then
  echo "Current userid not allowed to run Director CLIs, make sure running with proper administrator userid."
  echo "NOTE: When using LDAP, add -user and -pw on the command line."
  exit 2
fi

# Disable zip option on AIX
AEM_TAR_Z="z"
AEM_TAR_EXT=".tgz"
AEM_UNAME=`uname`
if [ "$AEM_UNAME" == 'AIX' ] ; then
   AEM_TAR_Z=""
   AEM_TAR_EXT=".tar"
fi

# Setup output file names
AEMFILE=aemmedic.txt
OUTFILE=$AEM_DIR/$AEMFILE
TARFILE=$AEM_DIR/aemmedic$AEM_TAR_EXT

# Clear out file
rm -f $OUTFILE 1> /dev/null 2>&1

echo "===================== Active Energy Manager =======================" >> $OUTFILE
echo "======================== AEM Medic $AEM_MEDIC_VER ============================" >> $OUTFILE
echo " "
echo "...collecting service information, please wait..."

echo "============================ DATE =================================" >> $OUTFILE
echo "Output from date:" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
date >> $OUTFILE

echo "============================= ID ==================================" >> $OUTFILE
echo "Output from id:" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
id >> $OUTFILE 2>&1

echo "============================= DIR =================================" >> $OUTFILE
echo "Output from dir $AEM_DIR:" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
ls -laR $AEM_DIR >> $OUTFILE 2>&1

echo "============================= PS ==================================" >> $OUTFILE
echo "Output from ps auxw:" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
ps auxw >> $OUTFILE 2>&1

echo "============================= DF ==================================" >> $OUTFILE
echo "Output from df:" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
df >> $OUTFILE 2>&1

echo "============================= MOUNT ===============================" >> $OUTFILE
echo "Output from mount:">> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
mount >> $OUTFILE 2>&1

echo "============================= NETSTAT =============================" >> $OUTFILE
echo "Output from netstat -r:" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
netstat -r >> $OUTFILE 2>&1

echo "============================= ARP =================================" >> $OUTFILE
echo "Output from arp -a:" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
arp -a >> $OUTFILE 2>&1

echo "============================= DNS INFO ============================" >> $OUTFILE
echo "Output from cat /etc/resolv.conf:" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
cat /etc/resolv.conf >> $OUTFILE 2>&1

echo "============================= HOSTS INFO ==========================" >> $OUTFILE
echo "Output from cat /etc/hosts:" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
cat /etc/hosts >> $OUTFILE 2>&1

echo "============================ VERSION INFO =========================" >> $OUTFILE
echo "Output from cat /proc/version:" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
cat /proc/version >> $OUTFILE 2>&1

echo "============================ RELEASE INFO =========================" >> $OUTFILE
echo "Output from cat /etc/*-release" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
cat /etc/*-release >> $OUTFILE 2>&1

echo "============================= MEMORY INFO =========================" >> $OUTFILE
echo "Output from cat /proc/meminfo:" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
cat /proc/meminfo >> $OUTFILE 2>&1

echo "============================= CPU INFO ============================" >> $OUTFILE
echo "Output from cat /proc/cpuinfo:" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
cat /proc/cpuinfo >> $OUTFILE 2>&1

echo "============================= UNAME ===============================" >> $OUTFILE
echo "Output from uname -a:" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
uname -a >> $OUTFILE 2>&1

echo "============================= DMESG ===============================" >> $OUTFILE
echo "Output from dmesg:" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
dmesg >> $OUTFILE 2>&1

echo "============================= IFCONFIG ============================" >> $OUTFILE
echo "Output from ifconfig -am:" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
ifconfig -a >> $OUTFILE 2>&1

echo "==============================LOCALE ==============================" >> $OUTFILE
echo "Output from locale:" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
locale >> $OUTFILE 2>&1

echo "============================= SET SORT ============================" >> $OUTFILE
echo "Output from set | sort:" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
set | sort >> $OUTFILE 2>&1

echo "============================= RPM QA SORT==========================" >> $OUTFILE
echo "Output from rpm -qa | sort:" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
rpm -qa | sort >> $OUTFILE 2>&1

echo "============================= LD.SO.CONF INFO =====================" >> $OUTFILE
echo "cat /etc/ld.so.conf" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
cat /etc/ld.so.conf >> $OUTFILE 2>&1

##########
echo "...system information collected, starting AEM collection..., please wait..."
##########

echo "============================= AEM Properties 1 ====================" >> $OUTFILE
echo "cat $LWI_DIR/runtime/aem/AEM.properties" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
cat $LWI_DIR/runtime/aem/AEM.properties >> $OUTFILE 2>&1

echo "============================= AEM Properties 2 ====================" >> $OUTFILE
echo "cat $LWI_DIR/conf/overrides/AEM.properties" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
cat $LWI_DIR/conf/overrides/AEM.properties >> $OUTFILE 2>&1

echo "============================= AEM Dump Emr All ====================" >> $OUTFILE
echo "$BIN_DIR/smcli lspowerinfo --dumpemrall" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
$BIN_DIR/smcli $* lspowerinfo --dumpemrall >> $OUTFILE 2>&1

echo "============================= AEM Dump Emr Cache ==================" >> $OUTFILE
echo "$BIN_DIR/smcli lspowerinfo --dumpemrcache" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
$BIN_DIR/smcli $* lspowerinfo --dumpemrcache >> $OUTFILE 2>&1

echo "============================= AEM Dump Poll Queue =================" >> $OUTFILE
echo "$BIN_DIR/smcli lspowerinfo --dumppollingqueue" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
$BIN_DIR/smcli $* lspowerinfo --dumppollingqueue >> $OUTFILE 2>&1

echo "============================= AEM Dump Resource Queue =============" >> $OUTFILE
echo "$BIN_DIR/smcli lspowerinfo --dumpresourcequeue" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
$BIN_DIR/smcli $* lspowerinfo --dumpresourcequeue >> $OUTFILE 2>&1

echo "============================= AEM Dump DB Service Queue ===========" >> $OUTFILE
echo "$BIN_DIR/smcli lspowerinfo --dumpdbservicequeue" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
$BIN_DIR/smcli $* lspowerinfo --dumpdbservicequeue >> $OUTFILE 2>&1

echo "============================= AEM Dump Event Queue ================" >> $OUTFILE
echo "$BIN_DIR/smcli lspowerinfo --dumpeventqueue" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
$BIN_DIR/smcli $* lspowerinfo --dumpeventqueue >> $OUTFILE 2>&1

echo "============================= AEM Dump Table Stats ================" >> $OUTFILE
echo "$BIN_DIR/smcli lspowerinfo --dumptablestats" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
$BIN_DIR/smcli $* lspowerinfo --dumptablestats >> $OUTFILE 2>&1
echo "-------------------------------------------------------------------" >> $OUTFILE
echo "$BIN_DIR/smcli lspowerinfo --dumptablesummary" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
$BIN_DIR/smcli $* lspowerinfo --dumptablesummary >> $OUTFILE 2>&1

echo "============================= AEM Query HDC =======================" >> $OUTFILE
echo "$BIN_DIR/smcli lspowerinfo --queryhdc" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
$BIN_DIR/smcli $* lspowerinfo --queryhdc >> $OUTFILE 2>&1

echo "============================= AEM BC Connections ==================" >> $OUTFILE
echo "$BIN_DIR/smcli lspowerinfo --dumpbladecenterconn" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
$BIN_DIR/smcli $* lspowerinfo --dumpbladecenterconn >> $OUTFILE 2>&1

echo "============================= AEM Power Connections ===============" >> $OUTFILE
echo "$BIN_DIR/smcli lspowerinfo --dumppowerserverconn" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
$BIN_DIR/smcli $* lspowerinfo --dumppowerserverconn >> $OUTFILE 2>&1

echo "============================= AEM X Connections ===================" >> $OUTFILE
echo "$BIN_DIR/smcli lspowerinfo --dumpsystemxserverconn" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
$BIN_DIR/smcli $* lspowerinfo --dumpsystemxserverconn >> $OUTFILE 2>&1

echo "============================= AEM lspowerobjects ==================" >> $OUTFILE
echo "$BIN_DIR/smcli lspowerobjects" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
$BIN_DIR/smcli $* lspowerobjects >> $OUTFILE 2>&1

echo "============================= AEM lscollect =======================" >> $OUTFILE
echo "$BIN_DIR/smcli lscollect" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
$BIN_DIR/smcli $* lscollect >> $OUTFILE 2>&1

echo "============================= AEM lspowerinfo =====================" >> $OUTFILE
echo "$BIN_DIR/smcli lspowerinfo" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
$BIN_DIR/smcli $* lspowerinfo >> $OUTFILE 2>&1

echo "============================= AEM lspowerlast =====================" >> $OUTFILE
echo "$BIN_DIR/smcli lspowerlast" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
$BIN_DIR/smcli $* lspowerlast >> $OUTFILE 2>&1

echo "============================= AEM lspolicy ========================" >> $OUTFILE
echo "$BIN_DIR/smcli lspolicy" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
$BIN_DIR/smcli $* lspolicy >> $OUTFILE 2>&1

echo "============================= AEM getpcap =========================" >> $OUTFILE
echo "$BIN_DIR/smcli getpcap" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
$BIN_DIR/smcli $* getpcap >> $OUTFILE 2>&1

echo "============================= AEM getpsaver =======================" >> $OUTFILE
echo "$BIN_DIR/smcli getpsaver" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
$BIN_DIR/smcli $* getpsaver >> $OUTFILE 2>&1

echo "============================= AEM lsproperties ====================" >> $OUTFILE
echo "$BIN_DIR/smcli lsproperties" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
$BIN_DIR/smcli $* lsproperties >> $OUTFILE 2>&1

##########
echo "...AEM information collected, starting Director collection..., please wait..."
##########

echo "============================= Dir version =========================" >> $OUTFILE
echo "cat $DIR_DIR/version.*" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
cat $DIR_DIR/version.* >> $OUTFILE 2>&1

echo "============================= LWI Features ========================" >> $OUTFILE
echo "$LWI_DIR/bin/lwiupdatemgr.sh -listFeatures" >> $OUTFILE 2>&1
echo "-------------------------------------------------------------------" >> $OUTFILE
$LWI_DIR/bin/lwiupdatemgr.sh -listFeatures >> $OUTFILE 2>&1

echo "============================= LWI ListConfig ======================" >> $OUTFILE
echo "$LWI_DIR/bin/lwiupdatemgr.sh -listConfig" >> $OUTFILE 2>&1
echo "-------------------------------------------------------------------" >> $OUTFILE
$LWI_DIR/bin/lwiupdatemgr.sh -listConfig >> $OUTFILE 2>&1

echo "============================= Dir lsbundles =======================" >> $OUTFILE
echo "$BIN_DIR/smcli lsbundle" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
$BIN_DIR/smcli $* lsbundle >> $OUTFILE 2>&1

echo "============================= Dir lsupd ===========================" >> $OUTFILE
echo "$BIN_DIR/smcli lsupd" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
$BIN_DIR/smcli $* lsupd >> $OUTFILE 2>&1

echo "============================= Dir lssys ===========================" >> $OUTFILE
echo "$BIN_DIR/smcli lssys -o -T" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
$BIN_DIR/smcli $* lssys -o -T >> $OUTFILE 2>&1

echo "============================= Dir lsmeps ==========================" >> $OUTFILE
echo "$BIN_DIR/smcli lsmeps" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
$BIN_DIR/smcli $* lsmeps >> $OUTFILE 2>&1

for resource in PowerUnit PowerOutletGroup PowerOutlet LogicalModule SystemChassis Chassis PowerDomain Slot LogicalDevice PhysicalPackage BladeAdminServer Fan  PowerSupply Battery PowerSource Processor Card LogicalDevice Server HardwareManagementConsole Group GenericNetworkDevice PortController Sensor OperatingSystem CoolingDevice Rack PhysicalFrame Location Capability Service ResourceAllocationSettings SoftwareInstallation RemoteServiceAccessPoint IPProtocolEndpoint
do
  echo "============================= Dir lsresources =====================" >> $OUTFILE
  echo "$BIN_DIR/smcli lsresources $resource" >> $OUTFILE
  echo "-------------------------------------------------------------------" >> $OUTFILE
  $BIN_DIR/smcli $* lsresources $resource >> $OUTFILE 2>&1

  echo "============================= Dir lsrelationships2 src ============" >> $OUTFILE
  echo "$BIN_DIR/smcli lsrelationships2 -src $resource " >> $OUTFILE
  echo "-------------------------------------------------------------------" >> $OUTFILE
  $BIN_DIR/smcli $* lsrelationships2 -src $resource >> $OUTFILE 2>&1

  echo "============================= Dir lsrelationships2 tgt ============" >> $OUTFILE
  echo "$BIN_DIR/smcli lsrelationships2 -tgt $resource " >> $OUTFILE
  echo "-------------------------------------------------------------------" >> $OUTFILE
  $BIN_DIR/smcli $* lsrelationships2 -tgt $resource >> $OUTFILE 2>&1
done

echo "============================= Dir lsgp ============================" >> $OUTFILE
echo "$BIN_DIR/smcli lsgp -o -l" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
$BIN_DIR/smcli $* lsgp -o -l >> $OUTFILE 2>&1

echo "============================= Dir lsuser===========================" >> $OUTFILE
echo "$BIN_DIR/smcli lsuser -l" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
$BIN_DIR/smcli $* lsuser -l >> $OUTFILE 2>&1

echo "============================= Dir lsusergp ========================" >> $OUTFILE
echo "$BIN_DIR/smcli lsusergp -l" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
$BIN_DIR/smcli $* lsusergp -l >> $OUTFILE 2>&1

echo "============================= LWI Status ==========================" >> $OUTFILE
echo "$LWI_DIR/bin/lwistatus.sh" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
$LWI_DIR/bin/lwistatus.sh >> $OUTFILE 2>&1

echo "============================= LWI Plugin Status====================" >> $OUTFILE
echo "$LWI_DIR/bin/lwiplugin.sh -status" >> $OUTFILE
echo "-------------------------------------------------------------------" >> $OUTFILE
$LWI_DIR/bin/lwiplugin.sh -status >> $OUTFILE 2>&1

echo "-------------------------------------------------------------------" >> $OUTFILE
echo "----------------------------END------------------------------------" >> $OUTFILE

# Add in the install history if available
AEM_INSTALL_HISTORY=""
if [ -f $AEM_DIR/history.zip ] ; then
  AEM_INSTALL_HISTORY=history.zip
fi

# Now that we've got alot gathered up, tar it to save space
rm -f $TARFILE > /dev/null 2>&1
# Tar up the output
tar c"$AEM_TAR_Z"f $TARFILE -C $AEM_DIR $AEMFILE  $AEM_INSTALL_HISTORY  2>&1 | grep -v "Removing leading"

echo " "
echo "AEM Medic has produced the following file:"
ls -l $TARFILE
echo "If requested, please send this file \""$TARFILE"\" to IBM Service for analysis"
echo " "
echo "To view the contents of this file, enter the following commands:"
echo "tar xv"$AEM_TAR_Z"f "$TARFILE
echo "cat "$AEMFILE
echo " "
